@@ -11,10 +11,10 @@ from math import ceil
 from f61d.setu import *
 
 
-VERSION = (0,5,12)
+VERSION = (0,5,13)
 VERSION = '.'.join(map(str, VERSION))
 
-
+invert = lambda a,n:pow(a,-1,n)
 
 print(colored(LOGO.randlogo()+' v'+VERSION+'\n\n',choice(['red','yellow','green'])))
 print(colored("Welcome to F61D. Use Help() for help.",'green'))
@@ -82,6 +82,7 @@ def fuckStar():
             a = 1
             b = 1
             a,b = b,1
+            a,b = (a+b)**2,(a-b)**2
     for i in range(3):
         print('.',end='')
         time.sleep(0.4)
@@ -208,9 +209,7 @@ def yinyang():
 def gmgj(n, c1, c2, e1, e2):#共模攻击
     '''
         共模攻击
-        gmpy2 is required
     '''
-    from gmpy2 import invert
     def egcd(a, b):
         if b == 0:
             return a, 0
@@ -223,12 +222,15 @@ def gmgj(n, c1, c2, e1, e2):#共模攻击
     s2 = s[1]
     if s1 < 0:
         s1 = - s1
-        c1 = invert(c1, n)
+        c1 = pow(c1,-1,n)
     elif s2 < 0:
         s2 = - s2
-        c2 = invert(c2, n)
+        c2 = pow(c2,-1,n)
     m = pow(c1, s1, n) * pow(c2, s2, n) % n
-    print(bytes.fromhex(hex(m)[2:]))
+    try:
+        print(bytes.fromhex(hex(m)[2:]))
+    except Exception as e:
+        print(str(e))
     return m
 
 def crt(c_list,n_list):
@@ -239,12 +241,11 @@ def crt(c_list,n_list):
         ...
     '''
     from functools import reduce
-    from gmpy2 import invert
     sm = 0
     prod = reduce(lambda a, b: a * b, n_list)
     for n_i, a_i in zip(n_list, c_list):
         p = prod // n_i
-        sm += a_i * invert(p, n_i) * p
+        sm += a_i * pow(p,-1,n_i) * p
     return int(sm % prod)
 
 def mtank(outerPic,innerPic,output='tank.png'):
